@@ -12,7 +12,7 @@
     License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include <KItinerary/ExtractorEngine>
@@ -101,44 +101,15 @@ private Q_SLOTS:
             contextMsg.setContent(cf.readAll());
             contextMsg.parse();
             m_engine.setContext(&contextMsg);
+        } else {
+            m_engine.setContext(nullptr);
+            m_engine.setContextDate(QDateTime({2018, 1, 1}, {0, 0}));
         }
 
         QFile inFile(inputFile);
         QVERIFY(inFile.open(QFile::ReadOnly));
-
-        std::unique_ptr<KPkPass::Pass> pass;
-        std::unique_ptr<HtmlDocument> htmlDoc;
-        std::unique_ptr<PdfDocument> pdfDoc;
-        KCalCore::Calendar::Ptr calendar;
-        std::unique_ptr<KMime::Message> mimeMsg;
-        QJsonArray jsonResult;
-
-        if (inputFile.endsWith(QLatin1String(".pkpass"))) {
-            pass.reset(KPkPass::Pass::fromData(inFile.readAll()));
-            m_engine.setPass(pass.get());
-        } else if (inputFile.endsWith(QLatin1String(".pdf"))) {
-            pdfDoc.reset(PdfDocument::fromData(inFile.readAll()));
-            QVERIFY(pdfDoc);
-            m_engine.setPdfDocument(pdfDoc.get());
-        } else if (inputFile.endsWith(QLatin1String(".html"))) {
-            htmlDoc.reset(HtmlDocument::fromData(inFile.readAll()));
-            QVERIFY(htmlDoc);
-            m_engine.setHtmlDocument(htmlDoc.get());
-        } else if (inputFile.endsWith(QLatin1String(".txt"))) {
-            m_engine.setText(QString::fromUtf8(inFile.readAll()));
-        } else if (inputFile.endsWith(QLatin1String(".ics"))) {
-            calendar.reset(new KCalCore::MemoryCalendar(QTimeZone()));
-            KCalCore::ICalFormat format;
-            QVERIFY(format.fromRawString(calendar, inFile.readAll()));
-            m_engine.setCalendar(calendar);
-        } else if (inputFile.endsWith(QLatin1String(".eml")) || inputFile.endsWith(QLatin1String(".mbox"))) {
-            mimeMsg.reset(new KMime::Message);
-            mimeMsg->setContent(inFile.readAll());
-            mimeMsg->parse();
-            m_engine.setContent(mimeMsg.get());
-        }
-
-        jsonResult = m_engine.extract();
+        m_engine.setData(inFile.readAll(), inputFile);
+        auto jsonResult = m_engine.extract();
 
         const auto expectedSkip = QFile::exists(inputFile + QLatin1String(".skip"));
         if (jsonResult.isEmpty() && expectedSkip) {
@@ -151,8 +122,12 @@ private Q_SLOTS:
         postproc.setContextDate(contextMsg.date()->dateTime());
         postproc.process(result);
         const auto postProcResult = JsonLdDocument::toJson(postproc.result());
+        if (postProcResult.isEmpty() && expectedSkip) {
+            QSKIP("result filtered");
+            return;
+        }
         if (postProcResult.isEmpty()) {
-            qDebug() << "Result discared in post processing:";
+            qDebug() << "Result discarded in post processing:";
             qDebug().noquote() << QJsonDocument(jsonResult).toJson();
         }
         QVERIFY(!postProcResult.isEmpty());
