@@ -12,7 +12,7 @@
     License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KITINERARY_BARCODEDECODER_H
@@ -39,6 +39,9 @@ namespace BarcodeDecoder
 
     /** Decode an Aztec barcode containing binary data (such as UIC 918.3 codes). */
     KITINERARY_EXPORT QByteArray decodeAztecBinary(const QImage &img);
+
+    /** Decode an QRCode barcode containing text data. */
+    KITINERARY_EXPORT QString decodeQRCode(const QImage &img);
 }
 
 }
