@@ -12,7 +12,7 @@
     License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "traintrip.h"
@@ -36,6 +36,7 @@ public:
     TrainStation departureStation;
     Organization provider;
     QDateTime departureTime;
+    QDate departureDay;
     QString trainName;
     QString trainNumber;
 };
@@ -52,6 +53,22 @@ KITINERARY_MAKE_PROPERTY(TrainTrip, QString, trainName, setTrainName)
 KITINERARY_MAKE_PROPERTY(TrainTrip, QString, trainNumber, setTrainNumber)
 KITINERARY_MAKE_OPERATOR(TrainTrip)
 
+QDate TrainTrip::departureDay() const
+{
+    if (d->departureTime.isValid()) {
+        return d->departureTime.date();
+    }
+    return d->departureDay;
+}
+
+void TrainTrip::setDepartureDay(const QDate &value)
+{
+    if (departureDay() != value) {
+        d.detach();
+        d->departureDay = value;
+    }
+}
+
 }
 
 #include "moc_traintrip.cpp"
