@@ -12,13 +12,13 @@
     License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KITINERARY_JSAPI_BARCODE_H
 #define KITINERARY_JSAPI_BARCODE_H
 
-#include <QDate>
+#include <QDateTime>
 #include <QObject>
 
 namespace KItinerary {
@@ -55,11 +55,11 @@ public:
     Q_INVOKABLE QString toBase64(const QVariant &b) const;
 
     ///@cond internal
-    void setContextDate(const QDate &date);
+    void setContextDate(const QDateTime &dt);
     ///@endcond
 
 private:
-    QDate m_contextDate;
+    QDateTime m_contextDate;
 };
 
 }
