@@ -12,7 +12,7 @@
     License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "countrydbgenerator.h"
@@ -226,7 +226,7 @@ void CountryDbGenerator::writeCountryTable(QIODevice *out)
         out->write(", {");
         QStringList plugTypes;
         plugTypes.reserve((*countryIt).powerPlugTypes.size());
-        for (const auto &plugType : (*countryIt).powerPlugTypes) {
+        for (const auto &plugType : qAsConst((*countryIt).powerPlugTypes)) {
             const auto it = std::find_if(plug_type_table, plug_type_table_end, [plugType](const plug_type_mapping &elem) {
                 return QLatin1String(elem.wikidataId) == plugType;
             });
